@@ -7,7 +7,7 @@ def aggregation_chart(
     title: Optional[str] = None,
     page_size: int = 20,
     show_frequencies: bool = False,
-    sort_direction: str = "Descending",
+    sort_direction: str = "desc",
 ):
     """
     Example for aggregates
@@ -41,15 +41,31 @@ def aggregation_chart(
                 {
                     "type": "datasetAggregation",
                     "attrs": {
-                        "aggregates": groupby + metric,
-                        "datasetId": "",
-                        "displayType": "column",
-                        "sortBy": "",
-                        "sortDirection": sort_direction,
-                        "title": "" if title is None else title,
-                        "showFrequencies": show_frequencies,
-                        "pageSize": page_size,
-                        "timeseries": {},
+                        "uid": "",
+                        "title": title,
+                        "chartType": "column",
+                        "filters": [],
+                        "xAxis": {
+                            "fields": [],
+                            "numResults": page_size,
+                            "resortAlphanumerically": False,
+                        },
+                        "yAxis": {
+                            "fields": [],
+                            "showFrequency": show_frequencies,
+                            "sortBy": "",
+                            "sortDirection": sort_direction,
+                        },
+                        "timeseries": {
+                            "field": "insert_date_",
+                            "interval": "monthly",
+                        },
+                        "sentiment": {
+                            "field": "",
+                            "mode": "overview",
+                            "interval": "monthly",
+                        },
+                        "wordCloud": {"mode": "cloud"},
                     },
                 }
             ],
