@@ -1,3 +1,6 @@
+import uuid
+import numpy as np
+
 from typing import Union, Optional, Dict, Any, List
 
 from ai_dashboard.api import endpoints
@@ -7,6 +10,9 @@ from ai_dashboard.tabs.data_report import aggregation_chart
 from ai_dashboard.tabs.data_report import metric
 from ai_dashboard.tabs.data_report import markdown
 from ai_dashboard.tabs.data_report import image
+from ai_dashboard.constants import Colours
+
+import plotly.express as px
 
 
 class DataReport(abstract_tab.Tab):
@@ -15,7 +21,12 @@ class DataReport(abstract_tab.Tab):
     BLANK: Dict[str, Any] = {
         "activeFilterGroup": "",
         "color": None,
-        "configuration": {},
+        "configuration": {
+            "content": {
+                "type": "doc",
+                "content": [],
+            }
+        },
         "name": "",
         "type": ID,
     }
@@ -41,7 +52,11 @@ class DataReport(abstract_tab.Tab):
 
         self.dataset_id = dataset_id
 
-        self.config["colour"] = colour.upper() if colour is not None else colour
+        if colour is not None:
+            colour_values = list(map(lambda x: x._value_, Colours))
+            assert colour in colour_values, f"Colour must one of {colour_values}"
+
+        self.config["colour"] = colour
         self.config["configuration"]["title"] = title
         self.config["name"] = name
 
@@ -100,7 +115,7 @@ class DataReport(abstract_tab.Tab):
         content = md.parse(text)
         data_report.config = {
             "name": name,
-            "type": "REPORT",
+            "type": cls.ID,
             "color": colour.upper() if colour is not None else colour,
             "configuration": {
                 "title": title,
@@ -177,7 +192,67 @@ class DataReport(abstract_tab.Tab):
         )
         self.config["configuration"]["content"]["content"] += chart
 
-    def add_image(self, image_src: str):
-        image_src = self.insert_local_medias([image_src])[0]
+    def add_image(self, image_src: Union[bytes, str]):
+        if isinstance(image_src, bytes):
+            presigned_urls = self._endpoints._get_file_upload_urls(
+                self.dataset_id,
+                files=[str(uuid.uuid4())],
+            )
+            url = presigned_urls["files"][0]["url"]
+            upload_url = presigned_urls["files"][0]["upload_url"]
+            response = self._endpoints._upload_media(
+                presigned_url=upload_url,
+                media_content=image_src,
+            )
+            image_src = url
+        else:
+            image_src = self.insert_local_medias([image_src])[0]
         chart = image.image(image_src)
         self.config["configuration"]["content"]["content"] += chart
+
+    def add_plotly(
+        self,
+        fig: Any,
+        title: str,
+        width: int = None,
+        height: int = None,
+        width_percentage: int = 100,
+        options=None,
+    ):
+        if options is None:
+            options = {"displayLogo": False}
+        try:
+            import plotly
+        except ImportError:
+            raise ImportError(
+                ".plotly requires plotly to be installed, install with 'pip install -U plotly'."
+            )
+        layout = fig._layout
+        if width:
+            layout["width"] = width
+        else:
+            if "width" in layout and layout["width"] == np.inf:
+                layout["width"] = "auto"
+        if height:
+            layout["height"] = height
+        else:
+            if "height" in layout and layout["height"] == np.inf:
+                layout["height"] = "auto"
+        chart = {
+            "type": "appBlock",
+            # "attrs" : {"id": str(uuid.uuid4())},
+            "content": [
+                {
+                    "attrs": {
+                        "height": "auto",
+                        "data": fig._data,
+                        "layout": layout,
+                        "options": options,
+                        "title": title,
+                        "width": f"{width_percentage}%",
+                    },
+                    "type": "plotlyChart",
+                }
+            ],
+        }
+        self.config["configuration"]["content"]["content"] += [chart]
